package com.example.onomatopoeiaback.controller;


import com.example.onomatopoeiaback.domain.employee.Employee;
import com.example.onomatopoeiaback.domain.employee.EmployeeDTO;
import com.example.onomatopoeiaback.domain.visit.Visit;
import com.example.onomatopoeiaback.domain.visit.VisitDTO;
import com.example.onomatopoeiaback.service.EmployeeService;
import com.example.onomatopoeiaback.service.VisitService;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/employee")
public class EmployeeController {
    private final VisitService visitService;
    private final EmployeeService employeeService;

    public EmployeeController(EmployeeService employeeService, VisitService visitService) {
        this.employeeService = employeeService;
        this.visitService = visitService;
    }

    @PostMapping("/create")
    @SecurityRequirement(name = "basicAuth")
    public ResponseEntity<Employee> createEmployee(@RequestBody EmployeeDTO employeeDTO) {
        return ResponseEntity.ok(employeeService.createEmployee(employeeDTO));
    }

    @GetMapping("/{username}/info")
    @SecurityRequirement(name = "basicAuth")
    public ResponseEntity<Employee> info(@PathVariable String username) {
        return ResponseEntity.ok(employeeService.info(username));
    }

    @GetMapping("/{username}/auth")
    @SecurityRequirement(name = "basicAuth")
    public ResponseEntity<Visit> auth(@PathVariable String username) {
        employeeService.auth(username);
        return new ResponseEntity<>(HttpStatus.OK);
    }

    @PatchMapping("/{username}/open")
    @SecurityRequirement(name = "basicAuth")
        public ResponseEntity<Visit> open(@PathVariable String username, @RequestBody VisitDTO visitDTO) {
        visitService.register(username, visitDTO);
        return new ResponseEntity<>(HttpStatus.OK);
    }
}
