package com.example.onomatopoeiaback.service;

import com.example.onomatopoeiaback.domain.employee.Employee;
import com.example.onomatopoeiaback.domain.employee.EmployeeDTO;
import com.example.onomatopoeiaback.exceptions.UnauthorizedException;
import com.example.onomatopoeiaback.repository.EmployeeRepository;
import com.example.onomatopoeiaback.repository.VisitRepository;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.stereotype.Service;

import java.util.Optional;

@Service
public class EmployeeService {

    private final EmployeeRepository employeeRepository;

    public EmployeeService(EmployeeRepository employeeRepository) {
        this.employeeRepository = employeeRepository;
    }

    public Employee createEmployee(EmployeeDTO employeeDTO) {
        BCryptPasswordEncoder passwordEncoder = new BCryptPasswordEncoder();

        Employee employee = new Employee();
        employee.setLogin(employeeDTO.getLogin());
        employee.setPassword(passwordEncoder.encode(employeeDTO.getPassword()));
        employee.setFirstName(employeeDTO.getFirstName());
        employee.setLastName(employeeDTO.getLastName());
        employee.setPatronymic(employeeDTO.getPatronymic());
        employee.setPhoto(employeeDTO.getPhoto());
        employee.setPosition(employeeDTO.getPosition());

        employee = employeeRepository.saveAndFlush(employee);
        return employee;
    }

    public void auth(String login) {
        Optional<Employee> employeeOptional = employeeRepository.findByLogin(login);

        if (employeeOptional.isEmpty()) {
            throw new UnauthorizedException();
        }
    }

    public Employee info(String login) {
        Optional<Employee> employeeOptional = employeeRepository.findByLogin(login);

        if (employeeOptional.isEmpty()) {
            throw new UnauthorizedException();
        }

        return employeeOptional.get();
    }
}
